==> xlr-server-23.1.13-sources.jar: com/xebialabs/deployit/plumbing/ImportResultsJsonWriter.java <==
package com.xebialabs.deployit.plumbing;

import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;
import java.lang.annotation.Annotation;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Collection;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import org.springframework.stereotype.Component;
import com.google.common.annotations.VisibleForTesting;

import com.xebialabs.xlrelease.views.ImportResult;
import com.xebialabs.xltype.serialization.json.JsonWriter;

import static com.google.common.base.Charsets.UTF_8;
import static com.xebialabs.deployit.plumbing.AbstractConfigurationItemReaderWriter.getClassFromGenericType;
import static com.xebialabs.xlrelease.repository.IdType.DOMAIN;

@Component
@Provider
@Produces({MediaType.APPLICATION_JSON, MediaType.TEXT_HTML})
public class ImportResultsJsonWriter implements MessageBodyWriter<Collection<ImportResult>> {
    @Override
    public boolean isWriteable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        if (Collection.class.isAssignableFrom(type) && genericType instanceof ParameterizedType) {
            type = getClassFromGenericType(genericType);
        }
        return ImportResult.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(Collection<ImportResult> importResults, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(Collection<ImportResult> importResults, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(importResults).getBytes(UTF_8));
    }

    @VisibleForTesting
    String toJson(Collection<ImportResult> importResults) {
        StringWriter stringWriter = new StringWriter();
        JsonWriter writer = new JsonWriter(stringWriter);
        writer.array();

        for (ImportResult importResult : importResults) {
            writeImportResult(writer, importResult);
        }

        writer.endArray();
        return stringWriter.toString();
    }

    static void writeImportResult(JsonWriter writer, ImportResult importResult) {
        writer.object();

        writer.key("id").value(DOMAIN.convertToViewId(importResult.getId()));
        writer.key("title").value(importResult.getTitle());

        writer.key("warnings");
        writer.array();
        for (String warning : importResult.getWarnings()) {
            writer.value(warning);
        }
        writer.endArray();

        writer.endObject();
    }
}

==> xlr-server-23.3.4-sources.jar: com/xebialabs/deployit/plumbing/ImportResultsJsonWriter.java <==
package com.xebialabs.deployit.plumbing;

import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;
import java.lang.annotation.Annotation;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.nio.charset.StandardCharsets;
import java.util.Collection;
import javax.ws.rs.Produces;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import javax.ws.rs.ext.Provider;
import org.springframework.stereotype.Component;
import com.google.common.annotations.VisibleForTesting;

import com.xebialabs.xlrelease.views.ImportResult;
import com.xebialabs.xltype.serialization.json.JsonWriter;

import static com.xebialabs.deployit.plumbing.AbstractConfigurationItemReaderWriter.getClassFromGenericType;
import static com.xebialabs.xlrelease.repository.IdType.DOMAIN;

@Component
@Provider
@Produces({MediaType.APPLICATION_JSON, MediaType.TEXT_HTML})
public class ImportResultsJsonWriter implements MessageBodyWriter<Collection<ImportResult>> {
    @Override
    public boolean isWriteable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        if (Collection.class.isAssignableFrom(type) && genericType instanceof ParameterizedType) {
            type = getClassFromGenericType(genericType);
        }
        return ImportResult.class.isAssignableFrom(type);
    }

    @Override
    public long getSize(Collection<ImportResult> importResults, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        return -1L;
    }

    @Override
    public void writeTo(Collection<ImportResult> importResults, Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream entityStream) throws IOException, WebApplicationException {
        entityStream.write(toJson(importResults).getBytes(StandardCharsets.UTF_8));
    }

    @VisibleForTesting
    String toJson(Collection<ImportResult> importResults) {
        StringWriter stringWriter = new StringWriter();
        JsonWriter writer = new JsonWriter(stringWriter);
        writer.array();

        for (ImportResult importResult : importResults) {
            writeImportResult(writer, importResult);
        }

        writer.endArray();
        return stringWriter.toString();
    }

    static void writeImportResult(JsonWriter writer, ImportResult importResult) {
        writer.object();

        writer.key("id").value(DOMAIN.convertToViewId(importResult.getId()));
        writer.key("title").value(importResult.getTitle());

        writer.key("warnings");
        writer.array();
        for (String warning : importResult.getWarnings()) {
            writer.value(warning);
        }
        writer.endArray();

        writer.endObject();
    }
}
